@@ -1,7 +1,7 @@
 /* gok-page-actions.c
 *
-* Copyright 2002, 2003 Sun Microsystems, Inc.,
-* Copyright 2002 University Of Toronto
+* Copyright 2002-2009 Sun Microsystems, Inc.,
+* Copyright 2002-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -25,6 +25,8 @@
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "gok-page-actions.h"
 #include "gok-action.h"
 #include "gok-input.h"
@@ -371,23 +373,17 @@ void gok_page_actions_button_clicked_change_name ()
 
 	/* create the 'new action name' dialog */
 	pDialogChangeName = gtk_dialog_new_with_buttons (_("GOK Action Name"),
-												GTK_WINDOW(gok_settingsdialog_get_window()),
-												GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-												GTK_STOCK_OK, GTK_RESPONSE_OK,
-												GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+							 GTK_WINDOW(gok_settingsdialog_get_window()),
+							 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+							 GTK_STOCK_OK, GTK_RESPONSE_OK,
+							 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
 	/* add a text label */
 	pLabel = gtk_label_new (_("Change the action name:"));
-	gtk_widget_ref (pLabel);
-	gtk_object_set_data_full (GTK_OBJECT (pDialogChangeName), "pLabel", pLabel,
-                            (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show (pLabel);
 	gtk_box_pack_start (GTK_BOX(GTK_DIALOG (pDialogChangeName)->vbox), pLabel, FALSE, FALSE, 0);
 
 	/* add a text entry */
 	pEntryNewName = gtk_entry_new ();
-	gtk_widget_ref (pEntryNewName);
-	gtk_object_set_data_full (GTK_OBJECT (pDialogChangeName), "Entry", pEntryNewName,
-                            (GtkDestroyNotify) gtk_widget_unref);
 	gtk_entry_set_text (GTK_ENTRY(pEntryNewName), m_pActionCurrent->pDisplayName);
 	gtk_widget_show (pEntryNewName);
 	gtk_box_pack_start (GTK_BOX(GTK_DIALOG (pDialogChangeName)->vbox), pEntryNewName, FALSE, FALSE, 0);
@@ -409,6 +405,7 @@ void gok_page_actions_button_clicked_change_name ()
 		/* check if the new action name is empty */
 		if (strlen (pNewName) == 0)
 		{
+			/*** TODO: code duplication ***/
 			pDialog = gtk_message_dialog_new (GTK_WINDOW(pDialogChangeName),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
@@ -428,6 +425,7 @@ void gok_page_actions_button_clicked_change_name ()
 			{
 				if (strcmp (pAction->pDisplayName, pNewName) == 0)
 				{
+					/*** TODO: code duplication ***/
 					pDialog = gtk_message_dialog_new (GTK_WINDOW(pDialogChangeName),
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
@@ -551,6 +549,7 @@ void gok_page_actions_button_clicked_delete ()
 
 	sprintf (buffer, _("Do you wish to delete this action (%s)?"), pNameAction);
 
+	/*** TODO: code duplication ***/
 	pDialog = gtk_message_dialog_new ((GtkWindow*)gok_settingsdialog_get_window(),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_QUESTION,
