@@ -24,6 +24,8 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include "gok-page-feedbacks.h"
 #include "gok-feedback.h"
 #include "gok-log.h"
